@@ -19,10 +19,11 @@ Plosurin::Grammar - Grammars for Closure Templates
 
 =cut
 package Plosurin::Grammar;
-use strict;
-use warnings;
+#use strict;
+#use warnings;
 use v5.10;
 use Regexp::Grammars;
+our $VERSION = '0.01';
 
 =head2 Plosurin::Template::Grammar - template file grammar
 
@@ -126,7 +127,7 @@ qr{
         ['"] <value=(?: ([^'"]+) )>  ['"]
 
     <token: variable>            \$?\w+ 
-    <objtoken: Soy::expression>  .*?
+    <objtoken: Soy::expressiong = expression >  .*?
     <objrule:  Soy::raw_text>    [^\{]+
 
 
