@@ -341,21 +341,6 @@ sub parse {
     else { return "BAD" }
 }
 
-package Soy::Expression;
-use strict;
-use warnings;
-use Regexp::Grammars;
-use Plosurin::Grammar;
-use base 'Soy::expressiong';
-our $VERSION = '0.01';
-
-sub new {
-    my $class = shift;
-    bless( ( $#_ == 0 ) ? { '' => shift } : {@_}, ref($class) || $class );
-}
-
-1;
-
 
 package Exp::base;
 use Data::Dumper;
